;;; -*- Mode: LISP; Package: USER; Base: 10 -*-
;;; $Header: /ct/debug/debugger.l,v 1.9 85/06/27 10:21:22 bill Exp $
(putprop 'debugger "$Revision: 1.9 $" 'rcs_revision)
;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;                                                                  ;;;
;;;                            debugger.l                           ;;;
;;;                                                                  ;;;
;;; William Brew                                       4-25-84       ;;;
;;;                                                                  ;;;
;;; This file is to be used to keep track of revisions to the        ;;;
;;; Ada debugger and to load the debugger.                           ;;;
;;;                                                                  ;;;
;;; This file is part of a proprietary software project.  Source     ;;;
;;; code and documentation describing implementation details are     ;;;
;;; available on a confidential, non-disclosure basis only.  These   ;;;
;;; materials, including this file in particular, are trade secrets  ;;;
;;; of Computer * Thought Corporation.                               ;;;
;;;                                                                  ;;;
;;; (c) Copyright 1982 and 1983,  Computer * Thought Corporation.    ;;;
;;;     All Rights Reserved.                                         ;;;
;;;                                                                  ;;;
;;; Reference materials:                                             ;;;
;;;   Foderaro and Sklower, The FRANZ LISP Manual, September 1981.   ;;;
;;;   Weinreb and Moon, LISP MACHINE MANUAL, Symbolics, July 1981.   ;;;
;;;   Charniak et al., 1980.  Artificial Intelligence Programming.   ;;;
;;;   Miller, 1982.  The C*T Ada Tutor: Guide to the Implementation. ;;;
;;;                                                                  ;;;
;;;   The following code assumes familiarity with these materials.   ;;;
;;;                                                                  ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Ensure presence of needed files. 

(comment Assumes ct_load and some suitable file_map are present)

(eval-when (compile load eval) (ct_load 'aip))	   ; AIP macros pkg. 

(eval-when (compile load eval) (ct_load 'compat))  ; Franz/LM compat pkg.


(eval-when (compile load eval) (ct_load 'ctstrl))  ; Compatable strings

(eval-when (load eval)              ; Load the main debugger files
  (ct_load 'dbutils)
  #+lispm  (ct_load 'lmdbcmds) #+franz (ct_load 'debugcmds)
  (ct_load 'envirwalk)
  (ct_load 'dianades)
  (ct_load 'codemon)
  (ct_load 'datamon)
  (ct_load 'adabugger))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Compiler Declarations and Global Variables -- 

#+franz (declare (macros t))
#+franz (setq *flavor-expand-macros* t)

(defconst *db%release* "1.9" "The release string for the Ada debugger.")

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Externally Callable Functions/Methods -- 

;;; Prepare for dumping

(defun db%dump_debugger ()
  (sstatus nofeature debugger_initialized)
  (db%init_debugger))


;;; Initialize the whole debugger.

(defun db%init_debugger ()
  (and (not (status feature debugger_initialized))
       (progn
	 (db%init_screens)			; Initialize the screens
	 (db%init_adabugger)			; Initialize the main module
	 (db%init_dbcmds)			; Initialize the window commands module
	 (db%init_nodenum)			; Initialize the node to number map
	 (db%init_dianatags)			; Initialize the tags
	 (db%init_dianades)			; Initialize the diana describer
	 (db%init_datades)                      ; Initialize the data value describer
	 (db%init_envirwalk)			; Initialize the environment walker
	 (db%init_codemon)			; Initialize the code monitors
	 (db%init_datamon)			; Initialize the data monitors
	 (db%init_dbutils)			; Initialize the utilities
	 (db%init_point)			; Initialize the pointing utilities
	 (sstatus feature debugger_initialized))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Internal Use Only Functions/Methods -- 

;;; eof
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

